#ifndef __CFL_BOX_H__
#define __CFL_BOX_H__

#include "cfl_macros.h"

#ifdef __cplusplus
extern "C" {
#endif

WIDGET_DECLARE(Fl_Box)

#ifdef __cplusplus
}
#endif
#endif
